summaryrefslogtreecommitdiff
path: root/src/SMAPI/Framework/ContentManagers/BaseContentManager.cs
diff options
context:
space:
mode:
authorJesse Plamondon-Willard <Pathoschild@users.noreply.github.com>2019-08-09 01:18:05 -0400
committerJesse Plamondon-Willard <Pathoschild@users.noreply.github.com>2019-09-14 19:08:06 -0400
commitfd77ae93d59222d70c86aebfc044f3af11063372 (patch)
tree76fac6ffc0cac70fb44f8b9ffc72471a2796a02f /src/SMAPI/Framework/ContentManagers/BaseContentManager.cs
parent3f6865e8301535c8fbe83bc0f931a116adac0636 (diff)
downloadSMAPI-fd77ae93d59222d70c86aebfc044f3af11063372.tar.gz
SMAPI-fd77ae93d59222d70c86aebfc044f3af11063372.tar.bz2
SMAPI-fd77ae93d59222d70c86aebfc044f3af11063372.zip
fix typos and inconsistent spelling
Diffstat (limited to 'src/SMAPI/Framework/ContentManagers/BaseContentManager.cs')
-rw-r--r--src/SMAPI/Framework/ContentManagers/BaseContentManager.cs34
1 files changed, 17 insertions, 17 deletions
diff --git a/src/SMAPI/Framework/ContentManagers/BaseContentManager.cs b/src/SMAPI/Framework/ContentManagers/BaseContentManager.cs
index fc558eb9..de39dbae 100644
--- a/src/SMAPI/Framework/ContentManagers/BaseContentManager.cs
+++ b/src/SMAPI/Framework/ContentManagers/BaseContentManager.cs
@@ -64,7 +64,7 @@ namespace StardewModdingAPI.Framework.ContentManagers
/// <param name="name">A name for the mod manager. Not guaranteed to be unique.</param>
/// <param name="serviceProvider">The service provider to use to locate services.</param>
/// <param name="rootDirectory">The root directory to search for content.</param>
- /// <param name="currentCulture">The current culture for which to localise content.</param>
+ /// <param name="currentCulture">The current culture for which to localize content.</param>
/// <param name="coordinator">The central coordinator which manages content managers.</param>
/// <param name="monitor">Encapsulates monitoring and logging.</param>
/// <param name="reflection">Simplifies access to private code.</param>
@@ -109,7 +109,7 @@ namespace StardewModdingAPI.Framework.ContentManagers
/// <param name="useCache">Whether to read/write the loaded asset to the asset cache.</param>
public abstract T Load<T>(string assetName, LocalizedContentManager.LanguageCode language, bool useCache);
- /// <summary>Load the base asset without localisation.</summary>
+ /// <summary>Load the base asset without localization.</summary>
/// <typeparam name="T">The type of asset to load.</typeparam>
/// <param name="assetName">The asset path relative to the loader root directory, not including the <c>.xnb</c> extension.</param>
[Obsolete("This method is implemented for the base game and should not be used directly. To load an asset from the underlying content manager directly, use " + nameof(BaseContentManager.RawLoad) + " instead.")]
@@ -121,19 +121,19 @@ namespace StardewModdingAPI.Framework.ContentManagers
/// <summary>Perform any cleanup needed when the locale changes.</summary>
public virtual void OnLocaleChanged() { }
- /// <summary>Normalise path separators in a file path. For asset keys, see <see cref="AssertAndNormaliseAssetName"/> instead.</summary>
- /// <param name="path">The file path to normalise.</param>
+ /// <summary>Normalize path separators in a file path. For asset keys, see <see cref="AssertAndNormalizeAssetName"/> instead.</summary>
+ /// <param name="path">The file path to normalize.</param>
[Pure]
- public string NormalisePathSeparators(string path)
+ public string NormalizePathSeparators(string path)
{
- return this.Cache.NormalisePathSeparators(path);
+ return this.Cache.NormalizePathSeparators(path);
}
/// <summary>Assert that the given key has a valid format and return a normalised form consistent with the underlying cache.</summary>
/// <param name="assetName">The asset key to check.</param>
/// <exception cref="SContentLoadException">The asset key is empty or contains invalid characters.</exception>
[SuppressMessage("ReSharper", "ParameterOnlyUsedForPreconditionCheck.Local", Justification = "Parameter is only used for assertion checks by design.")]
- public string AssertAndNormaliseAssetName(string assetName)
+ public string AssertAndNormalizeAssetName(string assetName)
{
// NOTE: the game checks for ContentLoadException to handle invalid keys, so avoid
// throwing other types like ArgumentException here.
@@ -142,7 +142,7 @@ namespace StardewModdingAPI.Framework.ContentManagers
if (assetName.Intersect(Path.GetInvalidPathChars()).Any())
throw new SContentLoadException("The asset key or local path contains invalid characters.");
- return this.Cache.NormaliseKey(assetName);
+ return this.Cache.NormalizeKey(assetName);
}
/****
@@ -165,8 +165,8 @@ namespace StardewModdingAPI.Framework.ContentManagers
/// <param name="assetName">The asset path relative to the loader root directory, not including the <c>.xnb</c> extension.</param>
public bool IsLoaded(string assetName)
{
- assetName = this.Cache.NormaliseKey(assetName);
- return this.IsNormalisedKeyLoaded(assetName);
+ assetName = this.Cache.NormalizeKey(assetName);
+ return this.IsNormalizedKeyLoaded(assetName);
}
/// <summary>Get the cached asset keys.</summary>
@@ -248,7 +248,7 @@ namespace StardewModdingAPI.Framework.ContentManagers
*********/
/// <summary>Load an asset file directly from the underlying content manager.</summary>
/// <typeparam name="T">The type of asset to load.</typeparam>
- /// <param name="assetName">The normalised asset key.</param>
+ /// <param name="assetName">The normalized asset key.</param>
/// <param name="useCache">Whether to read/write the loaded asset to the asset cache.</param>
protected virtual T RawLoad<T>(string assetName, bool useCache)
{
@@ -264,17 +264,17 @@ namespace StardewModdingAPI.Framework.ContentManagers
/// <param name="language">The language code for which to inject the asset.</param>
protected virtual void Inject<T>(string assetName, T value, LanguageCode language)
{
- assetName = this.AssertAndNormaliseAssetName(assetName);
+ assetName = this.AssertAndNormalizeAssetName(assetName);
this.Cache[assetName] = value;
}
/// <summary>Parse a cache key into its component parts.</summary>
/// <param name="cacheKey">The input cache key.</param>
/// <param name="assetName">The original asset name.</param>
- /// <param name="localeCode">The asset locale code (or <c>null</c> if not localised).</param>
+ /// <param name="localeCode">The asset locale code (or <c>null</c> if not localized).</param>
protected void ParseCacheKey(string cacheKey, out string assetName, out string localeCode)
{
- // handle localised key
+ // handle localized key
if (!string.IsNullOrWhiteSpace(cacheKey))
{
int lastSepIndex = cacheKey.LastIndexOf(".", StringComparison.InvariantCulture);
@@ -296,8 +296,8 @@ namespace StardewModdingAPI.Framework.ContentManagers
}
/// <summary>Get whether an asset has already been loaded.</summary>
- /// <param name="normalisedAssetName">The normalised asset name.</param>
- protected abstract bool IsNormalisedKeyLoaded(string normalisedAssetName);
+ /// <param name="normalizedAssetName">The normalized asset name.</param>
+ protected abstract bool IsNormalizedKeyLoaded(string normalizedAssetName);
/// <summary>Get the locale codes (like <c>ja-JP</c>) used in asset keys.</summary>
private IDictionary<LanguageCode, string> GetKeyLocales()
@@ -121,19 +121,19 @@ namespace StardewModdingAPI.Framework.ContentManagers
}
- /// <summary>Assert that the given key has a valid format and return a normalised form consistent with the underlying cache.</summary>
+ /// <summary>Assert that the given key has a valid format and return a normalized form consistent with the underlying cache.</summary>
/// <param name="assetName">The asset key to check.</param>
/// <exception cref="SContentLoadException">The asset key is empty or contains invalid characters.</exception>